@@ -105,6 +105,7 @@ Runtime native APIs have its IDs.
   81 build
   82 get_class_parent_class_id
   83 get_method_required_args_length
+  84 get_method_required_args_length
 
 =head1 Runtime Native APIs
 
@@ -449,3 +450,7 @@ Reserved.
 =head2 get_method_required_args_length
 
   int32_t (*get_method_required_args_length)(void* runtime, int32_t method_id);
+
+=head2 get_class_is_pointer
+
+  int32_t (*get_class_is_pointer)(void* runtime, int32_t class_id);
