@@ -11,7 +11,7 @@ SPVM::Point - Point
   use Point;
   
   my $point = Point->new;
-  my $point = Point->new_xy(1, 2);
+  my $point = Point->new(1, 2);
 
   $point->set_x(1);
   $point->set_y(2);
@@ -37,56 +37,56 @@ C<Point> class has the following interfaces.
 
 =back
 
+=head1 Fields
+
+=head2 x
+
+  has x : rw int;
+
+C<x>.
+
+=head2 y
+
+  has y : rw int;
+
+C<y>.
+
 =head1 Class Methods
 
 =head2 new
 
-  method new : Point ()
+  static method new : Point ($x = 0 : int, $y = 0 : int)
 
-Create a new C<Point> object.
+Create a new C<Point> object with L</"x"> and L</"y">.
 
 =head2 new_xy
 
   method new_xy : Point ($x : int, $y : int)
 
-Create a new C<Point> object with x and y.
+The alias for the following code using L</"new">
+
+  my $point = Point->new($x, $y);
+
+This method is deprecated and will be removed after 2022-09-03.
 
 =head1 Instance Methods
 
-=head2 x
+=head2 clear
 
-  method x : int ()
+  method clear : void ()
 
-Get C<x> field.
-
-=head2 set_x
-
-  void set_x : int ($x : int)
-
-Set C<x> field.
-
-=head2 y
-
-  method y : int ();
-
-Get C<y> field.
-
-=head2 set_y
-
-  void set_y : int ($y : int)
-
-Set C<y> field.
-
-=head2 to_string
-
-  method to_string : string ();
-
-Convert the C<Point> object to a string as the following.
-
-  (1,2)
+Set L</"x"> and L</"y"> to C<0>.
 
 =head2 cloneable_clone
 
   method cloneable_clone : object ()
 
-Clone a C<Point> object by create a new C<Point> object and C<x> and C<y> fields are copied to the new object.
+Create a new C<Point> object that clones myself.
+
+=head2 to_string
+
+  method to_string : string ();
+
+Stringify the C<Point> object as the following format.
+
+  (1,2)
